Add supported URI scheme to PhoneAccounts. (2/4)

Modify PhoneAccountRegistrar to load/save supported URI schemes to
the state XML file.
Added version check to state XML file and migration step to add
'sip' for SIPConnectionService PhoneAccounts, and 'tel' for all other
PhoneAccounts.

Bug: 17140110
Change-Id: Ic5d41254bade421cc39eb197a1d6fc2d6695f62f
diff --git a/src/com/android/telecomm/CallsManager.java b/src/com/android/telecomm/CallsManager.java
index 8935766..a7fb313 100644
--- a/src/com/android/telecomm/CallsManager.java
+++ b/src/com/android/telecomm/CallsManager.java
@@ -307,9 +307,11 @@
         }
 
         if (phoneAccountHandle == null) {
             // No preset account, check if default exists
             PhoneAccountHandle defaultAccountHandle =
-                    app.getPhoneAccountRegistrar().getDefaultOutgoingPhoneAccount();
+                    app.getPhoneAccountRegistrar().getDefaultOutgoingPhoneAccount(
+                            handle.getScheme());
             if (defaultAccountHandle != null) {
                 phoneAccountHandle = defaultAccountHandle;
             }
@@ -307,9 +307,11 @@
 
         if (phoneAccountHandle == null) {
-            // No preset account, check if default exists
+            // No preset account, check if default exists that supports the URI scheme for the
+            // handle.
             PhoneAccountHandle defaultAccountHandle =